.. :changelog:

History
-------

1.1.0 (2020-03-20)
++++++++++++++++++

* added possiblity to restrict access to non logged-in users to Facsimiles by adding TRANSKRIBUS_PUBLIC = False to settings


1.0.0 (2020-03-20)
++++++++++++++++++

* load staticfiles -> load static to be Django > 3.x compatible

0.3.0 (2019-10-24)
++++++++++++++++++

* more translations
* transkribus-css classes added to templates
* added TrpBaseModel

0.2.0 (2019-10-09)
++++++++++++++++++

* Added settings param for custom translations

0.1.0 (2019-10-02)
++++++++++++++++++

* First release.
